@@ -17,7 +17,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
 from .http import HttpClient
-from .models import Categories, Result
+from .models import CATEGORIES, Result
 
 
 class Client:
@@ -26,31 +26,27 @@ class Client:
     def __init__(self):
         self.http = HttpClient()
 
-    async def teardown(self):
+    async def get_image(self, category: str, amount: int = 1) -> Result:
         """
         |coro|
-        
-        A function to cleanup our http session.
-        """
-        await self.http.session.close()
 
-    async def get_image(self, category: str) -> Result:
-        """
-        |coro|
-        
         Returns an image URL of a specific category.
 
         Parameters
         ----------
         category: str
             The category of image you want to get.
-        
+        amount: int
+            The amount of images. Must be between 1 and 20.
+
         Returns
         -------
         nekosbest.Result
         """
-        if not Categories.has_value(category):
-            raise TypeError("This isn't a valid category.")
+        if not category in CATEGORIES:
+            raise ValueError("This isn't a valid category.")
+        if not 1 <= amount <= 20:
+            raise ValueError("Amount parameter must be between 1 and 20.")
 
-        result = await self.http.get(category)
+        result = await self.http.get(category, amount)
         return Result(result)
